OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "A palavra-passe está entre o 1,000,000 das mais comuns. Por favor torne-a única.",
    "Password needs to contain at least one numeric character." : "A palavra-passe precisa de conter pelo menos um caracter numérico.",
    "Password needs to contain at least one special character." : "A palavra-passe precisa de conter pelo menos um caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "A palavra-passe precisa de conter pelo menos uma letra minúscula e uma maiúscula.",
    "Password policy" : "Política de palavras-passe",
    "Saved" : "Guardado",
    "Forbid common passwords" : "palavras-passe comuns proibidas",
    "Enforce upper and lower case characters" : "Forçar letras maiúsculas e minúsculas",
    "Enforce numeric characters" : "Forçar caracteres numéricos",
    "Enforce special characters" : "Forçar caracteres especiais",
    "Unknown error" : "Erro desconhecido"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
